@@ -1,6 +1,9 @@
-from .pillow_jxl import *
+# ruff: noqa
+from .pillow_jxl import Decoder, Encoder
+
 from pillow_jxl import JpegXLImagePlugin
 
+
 __doc__ = pillow_jxl.__doc__
 if hasattr(pillow_jxl, "__all__"):
     __all__ = pillow_jxl.__all__
